# BatchResponseBatchedResultOrganizationInvitationBase

Returns a list of results in the same order as the inputs specified by the client.  Each result can succeed or fail independently of each other. Clients are expected to check the status of each result.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**results** | [**list[BatchedResultOrganizationInvitationBase]**](BatchedResultOrganizationInvitationBase.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


